@@ -1,4 +1,4 @@
-import os, cgi, os.path, deskbar, deskbar.Match, deskbar.Handler
+import os, cgi, os.path, deskbar, deskbar.Match, deskbar.Handler, deskbar.Utils
 import gnomevfs, gtk, gconf
 
 from gettext import gettext as _
@@ -69,7 +69,7 @@ class DeliciousMatch(deskbar.Match.Match):
 		}
 		
 	def action(self, text=None):
-		gnomevfs.url_show(self.url)
+		deskbar.Utils.url_show(self.url)
 
 	def get_category(self):
 		return "web"
@@ -116,7 +116,7 @@ class DeliciousTagQueryEngine:
 		#Get the info from del.icio.us and parse
 		url = DEFAULT_QUERY_TAG % (urllib.quote_plus(self._user), urllib.quote_plus(tag))
 
-		stream = urllib.urlopen(url)
+		stream = urllib.urlopen(url, proxies=deskbar.Utils.get_proxy())
 		dom = xml.dom.minidom.parse(stream)
 		stream.close()
 		
